@@ -1,4 +1,5 @@
 
+from logging import warning
 from .comment import strip_comment_line_with_symbol, strip_comments  # keep 'unused' imports
 from .encoders import TricksEncoder, json_date_time_encode, class_instance_encode, ClassInstanceEncoder  # keep 'unused' imports
 from .decoders import DuplicateJsonKeyException, TricksPairHook, json_date_time_hook, ClassInstanceHook, \
@@ -7,18 +8,31 @@ from .nonp import NoNumpyException, DEFAULT_ENCODERS, _cih_instance
 from . import nonp
 
 try:
-	from numpy import ndarray, asarray
+	from numpy import ndarray, asarray, generic
+	import numpy as nptypes
 except ImportError:
 	raise NoNumpyException('Could not load numpy, maybe it is not installed? If you do not want to use numpy encoding '
 		'or decoding, you can import the functions from json_tricks.nonp instead, which do not need numpy.')
 
 
 def numpy_encode(obj):
+	"""
+	Encodes numpy `ndarray`s as lists with meta data.
+	
+	Encodes numpy scalar types as Python equivalents. Special encoding is not possible,
+	because int64 (in py2) and float64 (in py2 and py3) are subclasses of primitives,
+	which never reach the encoder.
+	"""
 	if isinstance(obj, ndarray):
 		dct = dict(__ndarray__=obj.tolist(), dtype=str(obj.dtype), shape=obj.shape)
 		if len(obj.shape) > 1:
 			dct['Corder'] = obj.flags['C_CONTIGUOUS']
 		return dct
+	elif isinstance(obj, generic):
+		if NumpyEncoder.SHOW_SCALAR_WARNING:
+			NumpyEncoder.SHOW_SCALAR_WARNING = False
+			warning('json-tricks: numpy scalar serialization is experimental and may work differently in future versions')
+		return obj.item()
 	return obj
 
 
@@ -26,6 +40,8 @@ class NumpyEncoder(ClassInstanceEncoder):
 	"""
 	JSON encoder for numpy arrays.
 	"""
+	SHOW_SCALAR_WARNING = True  # show a warning that numpy scalar serialization is experimental
+	
 	def default(self, obj, *args, **kwargs):
 		"""
 		If input object is a ndarray it will be converted into a dict holding
@@ -47,21 +63,28 @@ def json_numpy_obj_hook(dct):
 		order = 'A'
 		if 'Corder' in dct:
 			order = 'C' if dct['Corder'] else 'F'
-		return asarray(dct['__ndarray__'], dtype=dct['dtype'], order=order)
+		if dct['shape']:
+			return asarray(dct['__ndarray__'], dtype=dct['dtype'], order=order)
+		else:
+			# print(dct['dtype'])
+			# print(getattr(nptypes, dct['dtype']))
+			dtype = getattr(nptypes, dct['dtype'])
+			return dtype(dct['__ndarray__'])
+			# return asarray(dct['__ndarray__'], dtype=dct['dtype'], order=order)
 	return dct
 
 
-DEFAULT_NP_ENCODERS = DEFAULT_ENCODERS + (numpy_encode,)
+DEFAULT_NP_ENCODERS = (numpy_encode,) + DEFAULT_ENCODERS  # numpy encode needs to be before complex
 DEFAULT_NP_HOOKS = (json_numpy_obj_hook, json_date_time_hook, _cih_instance, json_complex_hook,)
 
 
-def dumps(obj, sort_keys=None, cls=TricksEncoder, obj_encoders=DEFAULT_NP_ENCODERS, extra_obj_encoders=(),
-		compression=None, **jsonkwargs):
+def dumps(obj, sort_keys=None, cls=TricksEncoder, obj_encoders=DEFAULT_NP_ENCODERS,
+		extra_obj_encoders=(), compression=None, **jsonkwargs):
 	"""
 	Just like `nonp.dumps` but with numpy functionality enabled.
 	"""
-	return nonp.dumps(obj, sort_keys=sort_keys, cls=cls, obj_encoders=obj_encoders, extra_obj_encoders=extra_obj_encoders,
-        compression=compression, **jsonkwargs)
+	return nonp.dumps(obj, sort_keys=sort_keys, cls=cls, obj_encoders=obj_encoders,
+		extra_obj_encoders=extra_obj_encoders, compression=compression, **jsonkwargs)
 
 
 def dump(obj, fp, sort_keys=None, cls=TricksEncoder, obj_encoders=DEFAULT_NP_ENCODERS, extra_obj_encoders=(),
