@@ -7,7 +7,7 @@ import pytz
 from pytest import raises
 from collections import OrderedDict
 from datetime import datetime, date, time, timedelta
-from .test_class import MyTestCls, CustomEncodeCls
+from .test_class import MyTestCls, CustomEncodeCls, SubClass, SuperClass
 from .nonp import strip_comments, dump, dumps, load, loads, DuplicateJsonKeyException, is_py3, ENCODING
 from math import pi
 
@@ -95,6 +95,22 @@ def test_string_compression():
 	assert ordered_map == data3
 
 
+def test_flush_no_errors():
+	# just tests that flush doesn't cause problems; checking actual flushing is too messy.
+	path = join(mkdtemp(), 'pytest-nonp.json')
+	with open(path, 'wb+') as fh:
+		dump(nonpdata, fh, compression=True, force_flush=True)
+	with open(path, 'rb') as fh:
+		data2 = load(fh, decompression=True)
+	assert data2 == nonpdata
+	# flush non-file IO
+	sh = BytesIO()
+	try:
+		dump(ordered_map, fp=sh, compression=True, force_flush=True)
+	finally:
+		sh.close()
+
+
 def test_compression_with_comments():
 	sh = BytesIO()
 	if is_py3:
@@ -127,7 +143,6 @@ cls_instance_custom = CustomEncodeCls()
 
 def test_cls_instance_default():
 	json = dumps(cls_instance)
-	print(dumps(cls_instance, indent=4))
 	back = loads(json)
 	assert (cls_instance.s == back.s)
 	assert (cls_instance.dct == dict(back.dct))
@@ -146,6 +161,35 @@ def test_cls_instance_local():
 	loads(json, cls_lookup_map=globals())
 
 
+def test_cls_instance_inheritance():
+	inst = SubClass()
+	json = dumps(inst)
+	assert '42' not in json
+	back = loads(json)
+	assert inst == back
+	inst.set_attr()
+	json = dumps(inst)
+	assert '42' in json
+	back = loads(json)
+	assert inst == back
+
+
+def test_cls_attributes_unchanged():
+	"""
+	Test that class attributes are not restored. This would be undesirable,
+	because deserializing one instance could impact all other existing ones.
+	"""
+	SuperClass.cls_attr = 37
+	inst = SuperClass()
+	json = dumps(inst)
+	assert '37' not in json
+	SuperClass.cls_attr = 42
+	back = loads(json)
+	assert inst == back
+	assert inst.cls_attr == back.cls_attr == 42
+	SuperClass.cls_attr = 37
+
+
 def test_duplicates():
 	loads(test_json_duplicates, allow_duplicates=True)
 	with raises(DuplicateJsonKeyException):
